import { registerDataType } from '../vendors/organik';
import { BuiltInDataType } from '../types/data-type';
import { isBoolean, isNumber, isInteger, isString, isArray, isPlainObject, isDateValue, } from '../utils';
const stringDescriptor = {
    validator: isString,
    defaultValueGetter: () => '',
};
const listDescriptor = {
    validator: isArray,
    defaultValueGetter: () => [],
};
const objectDescriptor = {
    validator: isPlainObject,
    defaultValueGetter: () => ({}),
};
function isEnumValue(value) {
    return isNumber(value) || isString(value);
}
function isDateValueValid(value) {
    return value === '' || isDateValue(value);
}
[
    { name: BuiltInDataType.Boolean, validator: isBoolean, defaultValueGetter: () => false },
    { name: BuiltInDataType.Integer, validator: isInteger, defaultValueGetter: () => 0 },
    { name: BuiltInDataType.Float, validator: isNumber, defaultValueGetter: () => 0 },
    Object.assign({ name: BuiltInDataType.String }, stringDescriptor),
    Object.assign({ name: BuiltInDataType.Text }, stringDescriptor),
    { name: BuiltInDataType.Enum, validator: isEnumValue, defaultValueGetter: () => '' },
    {
        name: BuiltInDataType.MultiEnum,
        validator: value => isArray(value) && value.every(isEnumValue),
        defaultValueGetter: () => [],
    },
    {
        name: BuiltInDataType.Date,
        validator: value => isDateValueValid(value) ||
            (isArray(value) && (value.length === 0 || value.every(isDateValueValid))),
        defaultValueGetter: () => '',
    },
    Object.assign({ name: BuiltInDataType.OneToOne }, objectDescriptor),
    Object.assign({ name: BuiltInDataType.OneToMany }, listDescriptor),
    Object.assign({ name: BuiltInDataType.ManyToMany }, listDescriptor),
    Object.assign({ name: BuiltInDataType.ManyToOne }, objectDescriptor),
].forEach(registerDataType);
