import type { IconProviders } from 'petals-ui/dist/icon';
import type { FormControlSize } from 'petals-ui/dist/form-control';
import type { FormLayoutType } from 'petals-ui/dist/form';
import type { DensityType } from 'petals-ui/dist/data-table';
import type { ActionDescriptor } from '../vendors/organik';
import type { ActionRenderType, BooleanInputRenderType, EnumInputRenderType, DateInputRenderType } from './render-type';
interface ActionCommonBehaviors {
    renderType?: ActionRenderType;
    showIcon?: boolean;
    iconOnly?: boolean;
    disableWhenNoSelection?: boolean;
    createAction?: string | string[];
    editAction?: string | string[];
    submitAction?: string | string[];
    resetAction?: string | string[];
    cancelAction?: string | string[];
    deleteAction?: string | string[];
}
interface FilterCommonBehaviors {
    dateFilterRenderType?: DateInputRenderType;
    dateTimeFormat?: string;
    dateFormat?: string;
    showHintAsPlaceholder?: boolean;
    showValidationRulesAsNative?: boolean;
    showEmptyValueOption?: boolean;
    emptyValueOptionLabel?: string;
}
interface SearchCommonBehaviors {
    conditionPersists?: boolean;
    searchWhenSelectableFilterChange?: boolean;
}
interface FieldCommonBehaviors {
    booleanFieldRenderType?: BooleanInputRenderType;
    enumFieldRenderType?: EnumInputRenderType;
    dateFieldRenderType?: DateInputRenderType;
    dateTimeFormat?: string;
    dateFormat?: string;
    showUnavailableOption?: boolean;
    showHintAsPlaceholder?: boolean;
    showHintAtFormItem?: boolean;
    hintPositionOfFormItem?: 'explain' | 'label';
    hintIcon?: string;
    showValidationRulesAsNative?: boolean;
}
interface ViewCommonBehaviors {
    objectViewFormLayout?: FormLayoutType;
    objectViewFormControlLabelWidth?: number | string;
    objectViewFormControlSize?: FormControlSize;
    objectViewShowValidationMessage?: boolean;
    objectViewActionBarOutside?: boolean;
    objectViewActionBarAlignment?: 'left' | 'center' | 'right';
    objectViewDefaultActions?: (string | ActionDescriptor)[];
    listViewDensity?: DensityType;
    listViewPageSizes?: number[];
    listViewDefaultPageSize?: number;
}
interface CommonWidgetBehaviors {
    action?: ActionCommonBehaviors;
    filter?: FilterCommonBehaviors;
    search?: SearchCommonBehaviors;
    field?: FieldCommonBehaviors;
    view?: ViewCommonBehaviors;
}
interface ThemeBehavior {
    common?: CommonWidgetBehaviors;
    [key: string]: any;
}
declare type ThemeStyle = {
    [key: string]: string;
};
interface ThemeOptions {
    icon?: {
        providers?: IconProviders;
    };
    style?: ThemeStyle;
    behavior?: ThemeBehavior;
    template?: string;
}
export type { ThemeStyle, ThemeBehavior, ThemeOptions };
