import { isArray, isFunction } from '../vendors/toolbox';
import { isEnumField } from './is';
const cachedEnumOptionMap = new Map();
function cacheDynamicEnumOptions(moduleName, field, options) {
    if (!isEnumField(field)) {
        return;
    }
    if (!cachedEnumOptionMap.has(moduleName)) {
        cachedEnumOptionMap.set(moduleName, new Map());
    }
    const moduleSpecificCache = cachedEnumOptionMap.get(moduleName);
    if (moduleSpecificCache.has(field.name) ||
        !isFunction(field.options)) {
        return;
    }
    if (isArray(options)) {
        moduleSpecificCache.set(field.name, options);
        cachedEnumOptionMap.set(moduleName, moduleSpecificCache);
    }
    else {
        field.options().then(({ success, data }) => {
            if (success) {
                moduleSpecificCache.set(field.name, data);
                cachedEnumOptionMap.set(moduleName, moduleSpecificCache);
            }
        });
    }
}
function getCachedEnumOptions(moduleName, field) {
    return isEnumField(field) && cachedEnumOptionMap.has(moduleName)
        ? cachedEnumOptionMap.get(moduleName).get(field.name)
        : undefined;
}
function resolveRangePlaceholders(inputs, config) {
    const { fromField, fromPlaceholder, toField, toPlaceholder } = config;
    const labels = ['开始日期', '结束日期'];
    const placeholders = [];
    [
        { name: fromField, placeholder: fromPlaceholder },
        { name: toField, placeholder: toPlaceholder },
    ].forEach((targetField, idx) => {
        const { name, placeholder } = targetField;
        const input = name ? inputs.find(f => name === f.name) : undefined;
        placeholders[idx] = placeholder || `请选择${(input && input.label) || labels[idx]}`;
    });
    return placeholders;
}
export { cacheDynamicEnumOptions, getCachedEnumOptions, resolveRangePlaceholders };
