import { isString } from '../vendors/toolbox';
import { runExpression, } from '../vendors/organik';
import { BuiltInDataType } from '../types/data-type';
import { getBehaviorByKey } from './theme';
function getDefaultRenderTypeMapOfField() {
    return {
        [BuiltInDataType.Boolean]: getBehaviorByKey('common.field.booleanFieldRenderType'),
        [BuiltInDataType.Integer]: 'number',
        [BuiltInDataType.Float]: 'number',
        [BuiltInDataType.String]: 'input',
        [BuiltInDataType.Text]: 'textarea',
        [BuiltInDataType.Enum]: getBehaviorByKey('common.field.enumFieldRenderType'),
        [BuiltInDataType.MultiEnum]: 'select',
        [BuiltInDataType.Date]: getBehaviorByKey('common.field.dateFieldRenderType'),
        [BuiltInDataType.OneToOne]: 'select',
        [BuiltInDataType.OneToMany]: 'select',
        [BuiltInDataType.ManyToMany]: 'select',
        [BuiltInDataType.ManyToOne]: 'select',
    };
}
function resolveFieldRenderType({ renderType, dataType = '' }) {
    return renderType || getDefaultRenderTypeMapOfField()[dataType] || '';
}
function getDefaultRenderTypeMapOfFilter() {
    return {
        [BuiltInDataType.Boolean]: 'select',
        [BuiltInDataType.String]: 'input',
        [BuiltInDataType.Text]: 'input',
        [BuiltInDataType.Integer]: 'number',
        [BuiltInDataType.Float]: 'number',
        [BuiltInDataType.Enum]: 'select',
        [BuiltInDataType.MultiEnum]: 'select',
        [BuiltInDataType.Date]: getBehaviorByKey('common.filter.dateFilterRenderType'),
        [BuiltInDataType.OneToOne]: 'select',
        [BuiltInDataType.OneToMany]: 'select',
        [BuiltInDataType.ManyToMany]: 'select',
        [BuiltInDataType.ManyToOne]: 'select',
    };
}
function resolveFilterRenderType({ renderType, dataType = '' }) {
    return renderType || getDefaultRenderTypeMapOfFilter()[dataType] || '';
}
function isBoolOrExprTrue(value, boolOrExpr, defaultReturnValue) {
    return isString(boolOrExpr)
        ? !!runExpression({ value }, boolOrExpr, defaultReturnValue)
        : boolOrExpr === true;
}
function resolveFieldRequired(value, readonly, required) {
    return readonly ? false : isBoolOrExprTrue(value, required);
}
export { resolveFieldRenderType, resolveFilterRenderType, isBoolOrExprTrue, resolveFieldRequired };
