import { __awaiter, __rest } from "tslib";
import { isString, toPascalCase } from '../../vendors/toolbox';
import { getAppHelper, } from '../../vendors/organik';
import { getBehaviorByKey } from '../theme';
import { resolveWidgetCtor, resolveSafePropsFromConfig } from './base';
function resolveActionWidgetCtor(moduleContext, { action }) {
    return resolveWidgetCtor(moduleContext, action.widget, () => `${toPascalCase(action.renderType || getBehaviorByKey('common.action.renderType') || '')}ActionWidget`);
}
function executeClientAction(viewContext, action, config) {
    const appHelper = getAppHelper();
    const { danger, confirm, text, execute } = action;
    let beforeExecute;
    let needConfirm;
    if (danger) {
        needConfirm = confirm !== false;
    }
    else {
        needConfirm = !!confirm;
    }
    if (needConfirm) {
        beforeExecute = callback => appHelper.confirm(isString(confirm) ? confirm : `确定要${text || '执行此操作'}？`, {
            title: '提示',
            type: 'warning',
            affirmButton: callback,
        });
    }
    const executeAction = () => __awaiter(this, void 0, void 0, function* () {
        if (execute) {
            yield Promise.resolve(execute(viewContext, appHelper, (config || action.config || {})));
        }
    });
    if (beforeExecute) {
        beforeExecute(executeAction);
    }
    else {
        executeAction();
    }
}
function resolveButtonProps({ primary, danger }, config, disabled) {
    const props = { disabled };
    if (primary) {
        props.color = 'primary';
    }
    if (danger) {
        props.color = 'danger';
    }
    return Object.assign(Object.assign({}, props), resolveSafePropsFromConfig(config, ['text', 'disabled', 'onClick']));
}
function resolveIconProps({ icon }) {
    const props = {};
    if (icon) {
        props.refs = icon;
    }
    return props;
}
function resolveLinkProps(config) {
    return resolveSafePropsFromConfig(config, ['showIcon', 'iconOnly', 'icon']);
}
function resolveControlPropsAndEvents(props, options) {
    const { className } = options, events = __rest(options, ["className"]);
    const resolved = Object.assign({}, props);
    if (className) {
        resolved.className = className;
    }
    return { props: resolved, events };
}
export { resolveActionWidgetCtor, executeClientAction, resolveButtonProps, resolveIconProps, resolveLinkProps, resolveControlPropsAndEvents, };
