import { isNumeric, isFunction, capitalize, includes } from '../../vendors/toolbox';
import { BuiltInDataType } from '../../types/data-type';
import { cacheDynamicEnumOptions, getCachedEnumOptions } from '../input';
import { resolveFieldRenderType } from '../renderer';
import { resolveWidgetCtor } from './base';
function resolveFieldWidgetCtor(moduleContext, { field, readonly }) {
    return resolveWidgetCtor(moduleContext, field.widget, () => `${resolveFieldRenderType(field)
        .split('-')
        .map(part => capitalize(part))
        .join('')}${readonly ? 'Read' : 'Edit'}${(field.dataType || '')
        .split('-')
        .map(part => capitalize(part))
        .join('')}FieldWidget`);
}
function resolvePlaceholder(fieldOrFilter, behaviorFromConfig, behaviorFromTheme) {
    let defaultPlaceholder = '';
    if (fieldOrFilter.dataType) {
        defaultPlaceholder = `${includes(fieldOrFilter.dataType, [
            BuiltInDataType.Integer,
            BuiltInDataType.Float,
            BuiltInDataType.String,
            BuiltInDataType.Text,
        ])
            ? '请输入'
            : '请选择'}${fieldOrFilter.label || ''}`;
    }
    const showHintAsPlaceholder = behaviorFromConfig === undefined ? behaviorFromTheme : behaviorFromConfig;
    const placeholder = fieldOrFilter.placeholder || defaultPlaceholder;
    return showHintAsPlaceholder ? fieldOrFilter.hint || placeholder : placeholder;
}
function resolveEnumOptions(context, fieldOrFilter, callback) {
    const { options } = fieldOrFilter;
    if (isFunction(options)) {
        const moduleName = context.getModuleContext().getModuleName();
        const cachedOptions = getCachedEnumOptions(moduleName, fieldOrFilter);
        if (cachedOptions) {
            callback(cachedOptions);
        }
        else {
            options().then(({ success, data }) => {
                if (success) {
                    cacheDynamicEnumOptions(moduleName, fieldOrFilter, data);
                    callback(data);
                }
            });
        }
    }
    else {
        callback(options || []); // eslint-disable-line node/no-callback-literal
    }
}
function resolveSingleEnumDisplayText(value, options) {
    const chosen = options.find(opt => isNumeric(opt.value) && isNumeric(value)
        ? Number(opt.value) === Number(value)
        : opt.value === value);
    return chosen ? chosen.label : '';
}
function resolveMultipleEnumDisplayText(value, optionMap) {
    return (value || [])
        .map(v => (v != null && optionMap[v] ? optionMap[v].label : v))
        .join('、');
}
export { resolveFieldWidgetCtor, resolvePlaceholder, resolveEnumOptions, resolveSingleEnumDisplayText, resolveMultipleEnumDisplayText, };
