import { ComponentCtor, DataValue, ConfigType, ActionContextType, ActionAuthorityGetter, ClientAction, ActionGroupByContext, ViewFieldDescriptor, ViewDescriptor, ModuleContext, ViewContextDescriptor, ViewContext as IViewContext, ListViewContext as IListViewContext, ObjectViewContext as IObjectViewContext } from '../../core';
import { ValueContext } from '../value';
declare type ViewContextOpener<VT, CT extends ConfigType> = IListViewContext<VT, CT> | IObjectViewContext<VT, CT> | undefined;
declare class ViewContext<ValueType extends DataValue = DataValue, Config extends ConfigType = ConfigType> extends ValueContext<ValueType> implements IViewContext<ValueType, Config> {
    private readonly id;
    private readonly moduleContext;
    private readonly options;
    private readonly fields;
    private readonly actions;
    private readonly opener;
    protected readonly actionContextGroups: ActionGroupByContext;
    private dataSource;
    private busy;
    constructor(moduleContext: ModuleContext, options: ViewContextDescriptor<ValueType, Config>);
    getId(): string;
    getModuleContext(): ModuleContext;
    /**
     * Get opener opened this view (pop-up view)
     *
     * @returns the opener that open this view
     */
    getOpener(): ViewContextOpener<ValueType, Config>;
    getComponents(): Record<string, ComponentCtor>;
    getView(): ViewDescriptor<Config>;
    getFields(): ViewFieldDescriptor[];
    getActions(): ClientAction[];
    getActionsByContextType(contextType: ActionContextType): ClientAction[];
    getActionsAuthority(): string | ActionAuthorityGetter | undefined;
    getConfig(): Config;
    getDataSource(): ValueType;
    setDataSource(data: ValueType): void;
    getBusy(): boolean;
    setBusy(busy: boolean): void;
}
export { ViewContext };
