import { isString, isFunction, noop, clone } from '@ntks/toolbox';
function resolveUrl(location) {
    return isString(location) ? location : location.path || '';
}
let authorityMapGetter = () => null;
function setUserAuthorityGetter(newGetter) {
    authorityMapGetter = newGetter;
}
function getUserAuthority() {
    return authorityMapGetter();
}
let appHelper = {
    history: {
        getLocation() {
            return {
                name: '',
                path: location.pathname,
                rawPath: location.pathname,
                hash: location.hash,
                query: {},
                params: {},
                ancestors: [],
            };
        },
        back: window.history.back,
        forward: window.history.forward,
        go: window.history.go,
        push(location) {
            return window.history.pushState({}, '', resolveUrl(location));
        },
        replace(location) {
            return window.history.replaceState({}, '', resolveUrl(location));
        },
    },
    session: {
        getAuthority: getUserAuthority,
    },
    alert(message, callback) {
        window.alert(message);
        if (isFunction(callback)) {
            callback();
        }
    },
    confirm: window.confirm,
    success: noop,
    error: noop,
    warning: noop,
    info: noop,
};
function getAppHelperForInternalUse() {
    return appHelper;
}
function registerAppHelper(helper) {
    appHelper = Object.assign(Object.assign({}, clone(helper)), { session: {
            getAuthority: getUserAuthority,
        } });
}
function getAppHelper() {
    return clone(appHelper);
}
export { setUserAuthorityGetter, getAppHelperForInternalUse, registerAppHelper, getAppHelper };
