import { executeClientAction } from '../../utils/widget/action';
import { BaseHeadlessWidget } from '../base';
class ActionHeadlessWidget extends BaseHeadlessWidget {
    getAction() {
        return this.getProp('action');
    }
    getConfig() {
        return this.getAction().config || {};
    }
    resolveClassNames(className) {
        return ['ActionWidget', className, this.getConfig().className].filter(cls => !!cls).join(' ');
    }
    /**
     * Execute client action with view context
     *
     * @param viewContext injected view context
     */
    execute(viewContext) {
        executeClientAction(viewContext, this.getAction(), this.getConfig());
    }
    /**
     * Render content of action widget
     *
     * @param iconWithTextRenderer render `Icon` component and text
     * @returns content of action widget
     */
    renderContent(iconWithTextRenderer) {
        const text = this.getAction().text || '';
        let { showIcon, iconOnly, icon } = this.getConfig();
        if (showIcon === undefined) {
            showIcon = this.getCommonBehavior('action.showIcon');
        }
        if (iconOnly === undefined) {
            iconOnly = this.getCommonBehavior('action.iconOnly');
        }
        return !showIcon || !icon ? text : iconWithTextRenderer(icon, text, iconOnly);
    }
}
export { ActionHeadlessWidget };
