import { isFunction, isUnixTimestamp, isDateValue, createMoment, resolveDateValue, resolveRangePlaceholders, } from '../../utils';
import { FieldHeadlessWidget } from './Field';
class DateFieldHeadlessWidget extends FieldHeadlessWidget {
    constructor() {
        super(...arguments);
        this.__defaultFormat = '';
    }
    setDefaultFormat(format) {
        this.__defaultFormat = format;
    }
    getDisplayFormat() {
        return this.getConfig().format || this.__defaultFormat;
    }
    getValueFormat() {
        return this.getConfig().valueFormat || this.getDisplayFormat();
    }
    formatDate(value) {
        const resolved = isUnixTimestamp(value) ? value * 1000 : value;
        return isFunction(this.getField().formatter)
            ? this.getField().formatter(resolved, this.getViewContext().getValue())
            : createMoment(resolved).format(this.getDisplayFormat());
    }
    resolveDateValue(date) {
        return resolveDateValue(date, this.getValueFormat());
    }
    /**
     * Get display date value
     *
     * @returns date value for display
     */
    getDateValue() {
        const value = this.getFieldValue();
        return isDateValue(value) ? this.formatDate(value) : value;
    }
    /**
     * Get display date range
     *
     * @returns date range for display
     */
    getRangeValue() {
        const { fromField, toField } = this.getConfig();
        let range;
        if (!fromField && !toField) {
            range = (this.getFieldValue() || []);
        }
        else {
            range = ['', ''];
            const context = this.getViewContext();
            if (fromField) {
                range[0] = context.getFieldValue(fromField) || '';
            }
            if (toField) {
                range[1] = context.getFieldValue(toField) || '';
            }
        }
        return range.map(date => (date ? this.formatDate(date) : date));
    }
    setRangeValue(dates, onChange) {
        const { fromField, toField } = this.getConfig();
        const range = dates ? dates.map(date => this.resolveDateValue(date)) : [];
        if (!fromField && !toField) {
            onChange(range);
        }
        const context = this.getViewContext();
        context.setFieldValue(fromField, range[0]);
        context.setFieldValue(toField, range[1]);
    }
    getRangePlaceholders() {
        return resolveRangePlaceholders(this.getViewContext().getFields(), this.getConfig());
    }
    getSeparator() {
        return this.getConfig().separator || '-';
    }
}
export { DateFieldHeadlessWidget };
