import { isUnixTimestamp, createMoment, resolveDateValue, resolveRangePlaceholders, } from '../../utils';
import { FilterHeadlessWidget } from './Filter';
class DateFilterHeadlessWidget extends FilterHeadlessWidget {
    constructor() {
        super(...arguments);
        this.__defaultFormat = '';
    }
    setDefaultFormat(format) {
        this.__defaultFormat = format;
    }
    getDisplayFormat() {
        return this.getConfig().format || this.__defaultFormat;
    }
    getValueFormat() {
        return this.getConfig().valueFormat || this.getDisplayFormat();
    }
    formatDate(value) {
        return createMoment(isUnixTimestamp(value) ? value * 1000 : value).format(this.getDisplayFormat());
    }
    resolveDateValue(date) {
        return resolveDateValue(date, this.getValueFormat());
    }
    /**
     * Get display date range
     *
     * @returns date range for display
     */
    getRangeValue() {
        const { fromField, toField } = this.getConfig();
        let range;
        if (!fromField && !toField) {
            range = (this.getFilterValue() || []);
        }
        else {
            range = ['', ''];
            const context = this.getSearchContext();
            if (fromField) {
                range[0] = context.getFilterValue(fromField) || '';
            }
            if (toField) {
                range[1] = context.getFilterValue(toField) || '';
            }
        }
        return range.map(date => (date ? this.formatDate(date) : date));
    }
    setRangeValue(dates, onChange) {
        const { fromField, toField } = this.getConfig();
        const range = dates ? dates.map(date => this.resolveDateValue(date)) : [];
        if (!fromField && !toField) {
            onChange(range);
        }
        const context = this.getSearchContext();
        context.setFilterValue(fromField, range[0]);
        context.setFilterValue(toField, range[1]);
    }
    getRangePlaceholders() {
        return resolveRangePlaceholders(this.getSearchContext().getFilters(), this.getConfig());
    }
    getSeparator() {
        return this.getConfig().separator || '-';
    }
}
export { DateFilterHeadlessWidget };
