import { isBoolean, isPlainObject } from '../../utils';
import { resolvePlaceholder } from '../../utils/widget';
import { BaseHeadlessWidget } from '../base';
class FilterHeadlessWidget extends BaseHeadlessWidget {
    getFilter() {
        return this.getProp('filter');
    }
    getFilterValue() {
        return this.getSearchContext().getFilterValue(this.getFilter().name);
    }
    getSearchContext() {
        return this.getViewContext().getSearchContext();
    }
    getConfig() {
        return (this.getFilter().config || {});
    }
    getPlaceholder() {
        return resolvePlaceholder(this.getFilter(), this.getConfig().showHintAsPlaceholder, this.getCommonBehavior('filter.showHintAsPlaceholder'));
    }
    isValidationRulesShownAsNative() {
        return this.getCommonBehavior('filter.showValidationRulesAsNative', false);
    }
    isImmediate() {
        const { searchImmediately } = this.getConfig();
        if (isBoolean(searchImmediately)) {
            return searchImmediately;
        }
        const searchDescriptor = this.getViewContext().getSearch();
        if (isPlainObject(searchDescriptor)) {
            const { searchWhenSelectableFilterChange } = searchDescriptor.config || {};
            if (isBoolean(searchWhenSelectableFilterChange)) {
                return searchWhenSelectableFilterChange;
            }
        }
        return this.getCommonBehavior('search.searchWhenSelectableFilterChange', false);
    }
}
export { FilterHeadlessWidget };
